@@ -264,7 +264,12 @@ class LogicEntrance:
     can_complete_raccoon_requests_6 = "Can Complete Raccoon Request 6"
     can_complete_raccoon_requests_7 = "Can Complete Raccoon Request 7"
     can_complete_raccoon_requests_8 = "Can Complete Raccoon Request 8"
-    buy_from_raccoon = "Buy From Raccoon"
+    buy_from_raccoon_1 = "Buy From Raccoon After 1 Request"
+    buy_from_raccoon_2 = "Buy From Raccoon After 2 Requests"
+    buy_from_raccoon_3 = "Buy From Raccoon After 3 Requests"
+    buy_from_raccoon_4 = "Buy From Raccoon After 4 Requests"
+    buy_from_raccoon_5 = "Buy From Raccoon After 5 Requests"
+    buy_from_raccoon_6 = "Buy From Raccoon After 6 Requests"
     fish_in_waterfall = "Fish In Waterfall"
     find_secret_notes = "Find Secret Notes"
     search_garbage_cans = "Search Garbage Cans"
